import { CheckboxOnChange, CheckboxState } from '../helpers/types';
/**
 * This is an interface for customizing the classes for
 * the `BulkCheckboxControl` component.
 */
export interface BulkCheckboxControlClasses {
    /**
     * The class for the "Select all" or "Deselect all" text.
     * This defaults to `link-primary text-decoration-none`.
     */
    selectRemoveAllText?: string;
}
/**
 * This is an interface for `BulkCheckboxControl` component props.
 */
export interface BulkCheckboxControlProps {
    /** Props to make the component controlled. */
    controlledProps?: {
        /**
         * A record, which key is the column prop name and the value
         * is of type `CheckboxState`.
         */
        checkboxState?: Record<string, CheckboxState>;
        /** The function fired when any checkbox in the table changes. */
        onCheckboxChange?: CheckboxOnChange;
        /**
         * The filtered data length. When not using filter control,
         * then this should equal to the table body's length.
         */
        filteredDataLength?: number;
    };
    /** Custom classes for the component. */
    classes?: BulkCheckboxControlClasses;
}
/**
 * Renders a control for selection or deselection of all rows. This is
 * only useful when pagination and checkbox are both enabled. When only
 * some (or none) of the rows are checked, then this will render the
 * number of checked rows, as well as the "Select all" button.
 * On the other hand, when all rows are selected, then it will
 * change to "Deselect all" button.
 */
export declare function BulkCheckboxControl({ controlledProps, classes }: BulkCheckboxControlProps): JSX.Element;
